@@ -8,23 +8,25 @@
 // <int>.<int>.<int>-<any text>.
 // or else upgrading old project file will not work
 // reliably.
-#define VERSION "0.11.0-Metis"
+#define VERSION "1.1.0-Pan (Unstable)"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to 
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 0110
-#define VERSION_INT 1100
+//#define VERSION_INT 110
+#define VERSION_INT 10100
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Metis"
+#define RELEASE_NAME "Pan (Unstable)"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis"
 #define QGIS_DATA_SUBDIR "share/qgis"
 
 #define HAVE_POSTGRESQL
 
+#define HAVE_SPATIALITE
+
 /* #undef HAVE_PYTHON */
 
 #endif
